@@ -1,16 +1,19 @@
+from .initialize import initialize
 from .monitor import monitor
+from .project import project
+from .protocol import protocol
 from .report import report
 from .retrieve import retrieve
 from .run import run
 from .sync_gcs import sync_gcs
-from .initialize import initialize
-
 
 __all__ = [
-           "monitor",
-           "report",
-           "retrieve",
-           "run",
-           "sync_gcs",
-           "initialize"
-          ]
+    "initialize",
+    "monitor",
+    "project",
+    "protocol",
+    "report",
+    "retrieve",
+    "run",
+    "sync_gcs",
+]
