@@ -8,6 +8,8 @@ from .core_experiment import (
     load_job_config,
     load_experiment_config,
     setup_proxy_server,
+    mle_config,
+    check_single_job_args,
 )
 from .core_files_load import (
     load_mle_toolbox_config,
@@ -19,6 +21,7 @@ from .load_hyper_log import load_hyper_log
 from .helpers import print_framed, get_jax_os_ready, save_pkl_object
 from .protocol_data import compose_protocol_data
 
+
 __all__ = [
     "parse_experiment_args",
     "get_extra_cmd_line_input",
@@ -38,4 +41,5 @@ __all__ = [
     "get_jax_os_ready",
     "save_pkl_object",
     "compose_protocol_data",
+    "check_single_job_args",
 ]
